
Required plugins to build this project
Install pip3 setup_tools wheel twine

Build this projecrt:
python3 setup.py sdist bdist_wheel



To install locally to make sure it works:
pip3 install dist/tpthello-0.1.0-py3-none-any.whl --force-reinstall